@@ -3,6 +3,7 @@ package cmd
 import (
 	"bufio"
 	"bytes"
+	"cmp"
 	"context"
 	"encoding/json"
 	"errors"
@@ -1221,7 +1222,7 @@ func (c *Config) editor(args []string) (string, []string, error) {
 	}
 
 	// Prefer $VISUAL over $EDITOR and fallback to the OS's default editor.
-	editCommand = firstNonEmptyString(os.Getenv("VISUAL"), os.Getenv("EDITOR"), defaultEditor)
+	editCommand = cmp.Or(os.Getenv("VISUAL"), os.Getenv("EDITOR"), defaultEditor)
 
 	return parseCommand(editCommand, append(editArgs, args...))
 }
@@ -1388,6 +1389,33 @@ func (c *Config) getGitleaksDetector() (*detect.Detector, error) {
 	return c.gitleaksDetector, c.gitleaksDetectorErr
 }
 
+// A modifyHTTPRequestFunc is a function that modifies a net/http.Request before
+// it is sent.
+type modifyHTTPRequestFunc func(*http.Request) (*http.Request, error)
+
+// A modifyHTTPRequestRoundTripper is a net/http.Transport that modifies the
+// request before it is sent.
+type modifyHTTPRequestRoundTripper struct {
+	modifyHTTPRequestFunc modifyHTTPRequestFunc
+	httpRoundTripper      http.RoundTripper
+}
+
+func newModifyHTTPRequestRoundTripper(f modifyHTTPRequestFunc, t http.RoundTripper) modifyHTTPRequestRoundTripper {
+	return modifyHTTPRequestRoundTripper{
+		modifyHTTPRequestFunc: f,
+		httpRoundTripper:      t,
+	}
+}
+
+// RoundTrip implements net/http.Transport.RoundTrip.
+func (m modifyHTTPRequestRoundTripper) RoundTrip(req *http.Request) (*http.Response, error) {
+	modifiedRequest, err := m.modifyHTTPRequestFunc(req)
+	if err != nil {
+		return nil, err
+	}
+	return m.httpRoundTripper.RoundTrip(modifiedRequest)
+}
+
 func (c *Config) getHTTPClient() (*http.Client, error) {
 	if c.httpClient != nil {
 		return c.httpClient, nil
@@ -1401,6 +1429,15 @@ func (c *Config) getHTTPClient() (*http.Client, error) {
 	httpTransport := httpcache.NewTransport(httpCache)
 	c.httpClient = httpTransport.Client()
 
+	c.httpClient.Transport = newModifyHTTPRequestRoundTripper(
+		func(req *http.Request) (*http.Request, error) {
+			req = req.Clone(req.Context())
+			req.Header.Add("User-Agent", "chezmoi.io/"+c.version.String())
+			return req, nil
+		},
+		c.httpClient.Transport,
+	)
+
 	return c.httpClient, nil
 }
 
@@ -2270,7 +2307,7 @@ func (c *Config) newTemplateData(cmd *cobra.Command) *templateData {
 	// solutions.
 	var gid, group, uid, username string
 	if runtime.GOOS == "android" {
-		username = firstNonEmptyString(os.Getenv("LOGNAME"), os.Getenv("USER"))
+		username = cmp.Or(os.Getenv("LOGNAME"), os.Getenv("USER"))
 	} else if currentUser, err := user.Current(); err == nil {
 		gid = currentUser.Gid
 		uid = currentUser.Uid
@@ -2753,7 +2790,7 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 			Command: "doppler",
 		},
 		Ejson: ejsonConfig{
-			KeyDir: firstNonEmptyString(os.Getenv("EJSON_KEYDIR"), "/opt/ejson/keys"),
+			KeyDir: cmp.Or(os.Getenv("EJSON_KEYDIR"), "/opt/ejson/keys"),
 		},
 		Gopass: gopassConfig{
 			Command: "gopass",
