@@ -9,12 +9,14 @@ import (
 
 func (c *Config) newHelpCmd() *cobra.Command {
 	helpCmd := &cobra.Command{
-		Use:         "help [command]",
-		Short:       "Print help about a command",
-		Long:        mustLongHelp("help"),
-		Example:     example("help"),
-		RunE:        c.runHelpCmd,
-		Annotations: newAnnotations(),
+		Use:     "help [command]",
+		Short:   "Print help about a command",
+		Long:    mustLongHelp("help"),
+		Example: example("help"),
+		RunE:    c.runHelpCmd,
+		Annotations: newAnnotations(
+			doesNotRequireValidConfig,
+		),
 	}
 
 	return helpCmd
