@@ -18,10 +18,9 @@ var (
 		regexp.MustCompile(`\A\.git\z`),
 		regexp.MustCompile(`\A\.idea\z`),
 		regexp.MustCompile(`\A\.vagrant\z`),
-		regexp.MustCompile(`\A\.venv\z`),
+		regexp.MustCompile(`\b\.?venv\b`),
 		regexp.MustCompile(`\A\.vscode\z`),
 		regexp.MustCompile(`\ACOMMIT\z`),
-		regexp.MustCompile(`\Aassets/chezmoi\.io/\.venv\z`),
 		regexp.MustCompile(`\Aassets/chezmoi\.io/site\z`),
 		regexp.MustCompile(`\Aassets/scripts/install\.ps1\z`),
 		regexp.MustCompile(`\Acompletions/chezmoi\.ps1\z`),
